@@ -16,6 +16,8 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
+
 #include <glib/gi18n.h>
 #include <stdlib.h>
 
@@ -75,7 +77,7 @@ on_window_activated_cb   (BjbWindowBase *window,
 
       if (win_is_available)
          bjb_window_base_switch_to_item (window, item);
-      
+
       else
          bijiben_new_window_internal (self, NULL, item, NULL);
 
@@ -110,12 +112,17 @@ bijiben_new_window_internal (Bijiben *self,
                              GError *error)
 {
   BjbWindowBase *window;
-  BijiNoteObj* note;
-  gchar *path;
+  BijiNoteObj   *note;
+  gchar         *path;
+  GList         *windows;
+  gboolean       not_first_window;
 
   note = NULL;
   path = NULL;
 
+  windows = gtk_application_get_windows (GTK_APPLICATION (self));
+  not_first_window = (gboolean) g_list_length (windows);
+
   if (file != NULL)
   {
     path = g_file_get_parse_name (file);
@@ -145,6 +152,9 @@ bijiben_new_window_internal (Bijiben *self,
     g_free (path);
 
   gtk_widget_show_all (GTK_WIDGET (window));
+
+  if (not_first_window)
+    gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
 }
 
 void
@@ -183,7 +193,7 @@ bijiben_open (GApplication  *application,
   {
     if (self->priv->is_loaded == TRUE)
       bijiben_new_window_internal (BIJIBEN_APPLICATION (application), files[i], NULL, NULL);
-    
+
     else
       g_queue_push_head (self->priv->to_open, g_file_get_parse_name (files[i]));
   }
@@ -357,6 +367,67 @@ bijiben_startup (GApplication *application)
   g_object_unref (storage);
 }
 
+static gboolean
+bijiben_application_local_command_line (GApplication *application,
+                                        gchar ***arguments,
+                                        gint *exit_status)
+{
+  gboolean version = FALSE;
+
+  const GOptionEntry options[] = {
+    { "version", 0, 0, G_OPTION_ARG_NONE, &version,
+      N_("Show the application's version"), NULL},
+    { NULL }
+  };
+  GOptionContext *context;
+  GError *error = NULL;
+  gint argc = 0;
+  gchar **argv = NULL;
+  *exit_status = EXIT_SUCCESS;
+
+  context = g_option_context_new (_("[FILE...]"));
+  g_option_context_set_summary (context,
+                                _("Take notes and export them everywhere."));
+  g_option_context_add_main_entries (context, options, NULL);
+  g_option_context_add_group (context, gtk_get_option_group (FALSE));
+
+  argv = *arguments;
+  argc = g_strv_length (argv);
+
+  if (!g_option_context_parse (context, &argc, &argv, &error)) {
+    /* Translators: this is a fatal error quit message printed on the
+     * command line */
+    g_printerr ("%s: %s\n", _("Could not parse arguments"), error->message);
+    g_error_free (error);
+
+    *exit_status = EXIT_FAILURE;
+    goto out;
+  }
+
+  if (version) {
+    g_print ("%s %s\n", _("GNOME Notes"), VERSION);
+    goto out;
+  }
+
+  g_application_register (application, NULL, &error);
+
+  if (error != NULL) {
+    /* Translators: this is a fatal error quit message printed on the
+     * command line */
+    g_printerr ("%s: %s\n",
+                _("Could not register the application"),
+                error->message);
+    g_error_free (error);
+
+    *exit_status = EXIT_FAILURE;
+    goto out;
+  }
+
+ out:
+  g_option_context_free (context);
+  return TRUE;
+}
+
 static void
 bijiben_finalize (GObject *object)
 {
@@ -378,6 +449,7 @@ bijiben_class_init (BijibenClass *klass)
   aclass->activate = bijiben_activate;
   aclass->open = bijiben_open;
   aclass->startup = bijiben_startup;
+  aclass->local_command_line = bijiben_application_local_command_line;
 
   oclass->finalize = bijiben_finalize;
 
